@@ -51,7 +51,7 @@ from serverly import default_sites
 from serverly.objects import Request, Response
 from serverly.utils import *
 
-version = "0.2.5"
+version = "0.2.6"
 description = "A really simple-to-use HTTP-server"
 address = ("localhost", 8080)
 name = "Serverly"
@@ -499,9 +499,14 @@ def register_error_response(code: int, msg_base: str, mode="enumerate"):
     - base: only return the base message
     """
     def enumer(*args):
-        return msg_base + ', '.join(args)
+        result = msg_base + ', '.join(args)
+        if result[-1] != ".":
+            result += "."
+        return result
 
     def base_only(*args):
+        if msg_base[-1] != ".":
+            msg_base += "."
         return msg_base
 
     if mode.lower() == "enumerate" or mode.lower() == "enum":
